@@ -7,8 +7,8 @@ use NBI::Job;
 use NBI::Opts;
 use base qw(Exporter);
 our @ISA = qw(Exporter);
-our @EXPORT = qw(Job Opts load_config %FORMAT_STRINGS);
-$NBI::Slurm::VERSION = '0.7.0';
+our @EXPORT = qw(Job Opts load_config has_queue %FORMAT_STRINGS);
+$NBI::Slurm::VERSION = '0.8.7';
 
 
 
@@ -71,19 +71,33 @@ sub has_squeue {
 sub queues {
   my $can_fail = shift;
   # Retrieve queues from SLURM
-  my $cmd = "sinfo --format '%P' --noheader";
-  my @output = `$cmd 2>/dev/null`;
-  if ($? != 0 and ! $can_fail) {
+  my $has_sinfo = `sinfo --version`;
+  chomp($has_sinfo);
+  if (not defined $has_sinfo and ! $can_fail) {
     Carp::croak "ERROR NBI::Slurm: sinfo failed. Are you in a SLURM cluster?\n";
   }
+  my $cmd = "timeout 5s sinfo --format '%P' --noheader";
+  my @output = `$cmd 2>/dev/null`;
+  if ($? != 0 and ! $can_fail) {
+    Carp::croak "ERROR NBI::Slurm: sinfo did not find queues. Are you in a SLURM cluster?\n";
+  }
+ 
   chomp @output;
   return @output;
 }
 
 sub valid_queue {
+  if ($ENV{'SKIP_SLURM_CHECK'}) {
+    return 1;
+  }
   my $queue = shift;
-  my @queues = queues(1);
+  my @queues = queues('CAN_FAIL');
   my @input_queues = split(/,/, $queue);
+
+  if (scalar(@input_queues) == 0) {
+    # Let's assume it exists... TODO CHECK
+    return  1;
+  }
   foreach my $input_queue (@input_queues) {
     if (! grep { $_ eq $input_queue } @queues) {
       return 0;
@@ -135,7 +149,7 @@ NBI::Slurm - NBI Slurm module
 
 =head1 VERSION
 
-version 0.7.0
+version 0.8.7
 
 =head1 SYNOPSIS
 
